==> binnie-mods-1.12.2-2.5.1.202-sources.jar: binnie/core/gui/BinnieGUIHandler.java <==
package binnie.core.gui;

import binnie.core.gui.minecraft.Window;
import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.world.World;
import net.minecraftforge.fml.common.network.IGuiHandler;
import net.minecraftforge.fml.relauncher.Side;
import net.minecraftforge.fml.relauncher.SideOnly;

import javax.annotation.Nullable;

public final class BinnieGUIHandler implements IGuiHandler {
	private final IBinnieGUID[] guiIds;

	public BinnieGUIHandler(final IBinnieGUID[] guiIds) {
		this.guiIds = guiIds;
	}

	@Override
	@Nullable
	public final Object getServerGuiElement(final int id, final EntityPlayer player, final World world, final int x, final int y, final int z) {
		Window window = this.getWindow(id, player, world, x, y, z, Side.SERVER);
		if (window == null) {
			return null;
		}
		window.initialiseServer();
		return window.getContainer();
	}

	@Override
	@Nullable
	@SideOnly(Side.CLIENT)
	public final Object getClientGuiElement(final int id, final EntityPlayer player, final World world, final int x, final int y, final int z) {
		if (!world.isRemote) {
			return this.getServerGuiElement(id, player, world, x, y, z);
		}
		Window window = this.getWindow(id, player, world, x, y, z, Side.CLIENT);
		if (window == null) {
			return null;
		}
		return window.getGui();
	}

	@Nullable
	public Window getWindow(final int id, final EntityPlayer player, final World world, final int x, final int y, final int z, final Side side) {
		for (IBinnieGUID guid : guiIds) {
			if (guid.ordinal() == id) {
				return guid.getWindow(player, world, x, y, z, side);
			}
		}
		return null;
	}
}

==> binnie-mods-1.12-2.3.0.24-sources.jar: binnie/core/gui/BinnieGUIHandler.java <==
package binnie.core.gui;

import javax.annotation.Nullable;

import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.world.World;

import net.minecraftforge.fml.common.network.IGuiHandler;
import net.minecraftforge.fml.relauncher.Side;
import net.minecraftforge.fml.relauncher.SideOnly;

import binnie.core.AbstractMod;
import binnie.core.gui.minecraft.Window;

public final class BinnieGUIHandler implements IGuiHandler {
	private AbstractMod mod;

	public BinnieGUIHandler(final AbstractMod mod) {
		this.mod = mod;
	}

	@Override
	@Nullable
	public final Object getServerGuiElement(final int id, final EntityPlayer player, final World world, final int x, final int y, final int z) {
		Window window = this.getWindow(id, player, world, x, y, z, Side.SERVER);
		if (window == null) {
			return null;
		}
		window.initialiseServer();
		return window.getContainer();
	}

	@Override
	@Nullable
	@SideOnly(Side.CLIENT)
	public final Object getClientGuiElement(final int id, final EntityPlayer player, final World world, final int x, final int y, final int z) {
		if (!world.isRemote) {
			return this.getServerGuiElement(id, player, world, x, y, z);
		}
		Window window = this.getWindow(id, player, world, x, y, z, Side.CLIENT);
		if (window == null) {
			return null;
		}
		return window.getGui();
	}

	@Nullable
	public Window getWindow(final int id, final EntityPlayer player, final World world, final int x, final int y, final int z, final Side side) {
		for (IBinnieGUID guid : this.mod.getGUIDs()) {
			if (guid.ordinal() == id) {
				return guid.getWindow(player, world, x, y, z, side);
			}
		}
		return null;
	}
}
